    -----------------------------------------------------------------------------
     MW6 Technologies QRCode ActiveX 3.0 (MW6QRCode.dll) Remote File Overwrite
     url: www.mw6tech.com

     Author: shinnai
     mail: shinnai[at]autistici[dot]org
     site: http://shinnai.altervista.org

     This was written for educational purpose. Use it at your own risk.
     Author will be not responsible for any damage.

     Tested on Windows XP Professional SP2 all patched, with Internet Explorer 7

     Description:
     This control contains two methods, "SaveAsBMP()" and "SaveAsWMF()", which
     write to a file specified as an argument.
     These can be exploited to overwrite and corrupt arbitrary files on the
     system in the context of the currently logged-on user.

     Marked as:
     RegKey Safe for Script: False
     RegKey Safe for Init: False
     Implements IObjectSafety: True
     IDisp Safe: Safe for untrusted: caller,data
     IPersist Safe: Safe for untrusted: caller,data
     IPStorage Safe: Safe for untrusted: caller,data
     KillBitSet: Falso
    -----------------------------------------------------------------------------

# milw0rm.com [2007-09-18]